import * as React from 'react';
import {
  Icon,
  Step,
  Button,
  Table,
  Radio,
  Form,
  Container,
  Checkbox,
} from 'semantic-ui-react';
import {
  Grid,
  Image,
  Label,
  Segment,
  Dropdown,
  Input,
  List,
  Accordion,
  Loader,
  DropdownItemProps, DropdownProps,
} from 'semantic-ui-react';

import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';
import Infra from '@overflow/infra/api/model/Infra';
import Domain from '@overflow/domain/api/model/Domain';

import Page from '@overflow/commons/api/model/Page';
import SensorRegistInfo from '../../api/model/SensorRegistInfo';

import SensorItemTree from '@overflow/meta/react/SensorItemTree';
import CrawlerSelectorContainer from '@overflow/meta/react/CrawlerSelector';




export interface SensorConfigStepperStateProps {
  steps?: Array<JSX.Element>;
  infraList?: Page;
  infra?: Infra;
  infraId?: number;
  setSensor?(data: SensorRegistInfo): void;
  getSensor?(): SensorRegistInfo;
}

export interface SensorConfigStepperDispatchProps {

}

export type SensorConfigStepperProps = SensorConfigStepperStateProps & SensorConfigStepperDispatchProps;

export interface SensorConfigStepperState {
  currentStep: number;
}

export class SensorConfigStepper extends React.Component<SensorConfigStepperProps, SensorConfigStepperState> {

  private selectOptions: Array<DropdownItemProps>;

  constructor(props: SensorConfigStepperProps, context: SensorConfigStepperState) {
    super(props, context);
    this.state = {
      currentStep: 1,
    };
  }



  public handleActive(idx: number): boolean {
    if (this.state.currentStep === idx) {
      return true;
    }
    return false;
  }

  public handleCompleted(idx: number): boolean {
    if (this.state.currentStep > idx) {
      return true;
    }
    return false;
  }

  public handlePrev(event: React.SyntheticEvent<HTMLAnchorElement>, data: object): void {
    let step: number = this.state.currentStep;
    if (step <= 1) {
      step = 1;
    } else {
      step--;
    }
    this.setState({
      currentStep: step,
    });
  }
  public handleNext(event: React.SyntheticEvent<HTMLAnchorElement>, data: object): void {
    let step: number = this.state.currentStep;
    if (step >= this.props.steps.length + 1) {
      step = this.props.steps.length + 1;
    } else {
      step++;
    }
    this.setState({
      currentStep: step,
    });
    if (step === this.props.steps.length + 1) {
      console.log('Done');
      console.log(this.props.getSensor());
    }
  }

  public showContent(): any {
    return this.props.steps[this.state.currentStep - 1];
  }

  public checkPrevDisabled(): boolean {
    if (this.state.currentStep <= 1) {
      return true;
    } else {
      return false;
    }
  }

  public checkNextDisabled(): boolean {
    if (this.state.currentStep === this.props.steps.length + 1) {
      return true;
    } else {
      return false;
    }
  }

  public convertInfraList(): void {

    if (this.props.infraList === undefined) {
      return null;
    }

    let selectionOptions: Array<DropdownItemProps> = new Array;

    for (let infra of this.props.infraList.content) {

      selectionOptions.push(this.createOption(infra));

    }
    this.selectOptions = selectionOptions;
  }

  public convertInfra(): void {
    if (this.props.infra === undefined) {
      return;
    }
    let selectionOptions: Array<DropdownItemProps> = new Array;

    selectionOptions.push(this.createOption(this.props.infra));
    this.selectOptions = selectionOptions;

    let sd = this.props.getSensor();
    sd.targetId = this.props.infra.target.id;
    this.props.setSensor(sd);
  }

  public createOption(infra: Infra): DropdownItemProps {
    let option = {
      key: infra.id,
      text: infra.infraType.name + '-' + infra.target.displayName,
      value: infra.target.id,
      // icon: 'check', // or close?
    };
    return option;
  }

  public defaultValue(): any {
    if (this.selectOptions !== undefined && this.selectOptions.length > 0) {
      return this.selectOptions[0].value;
    }
    return null;
  }

  public onChangeTarget(event: React.SyntheticEvent<HTMLElement>, data: DropdownProps): void {
    let sd = this.props.getSensor();

    sd.targetId = Number(data.value);
    this.props.setSensor(sd);
  }

  public renderInfra(): JSX.Element {

    if (this.props.infraId === undefined) {
      this.convertInfraList();
    } else {
      this.convertInfra();
    }

    return (<Dropdown
      placeholder='Select Target' selection options={this.selectOptions} defaultValue={this.defaultValue()}
      onChange={this.onChangeTarget.bind(this)} />);
  }

  public render(): JSX.Element {

    return (
      <Container fluid>
        <Step.Group fluid>
          <Step active={this.handleActive(1)} completed={this.handleCompleted(1)}>
            <Icon name='settings' color='grey' />
            <Step.Content title='Step 1' description='골라골라 크롤러를 골라' />
          </Step>

          <Step active={this.handleActive(2)} completed={this.handleCompleted(2)}>
            <Icon name='list ul' color='grey' />
            <Step.Content title='Step 2' description='골라골라 아이템도 골라' />
          </Step>

          <Step active={this.handleActive(3)} completed={this.handleCompleted(3)}>
            <Icon name='options' color='grey' />
            <Step.Content title='Step 3' description='나머지도 골라 아 빨리' />
          </Step>
        </Step.Group>
        {this.renderInfra()}
        {this.showContent()}
        <br />
        <Button.Group floated='right'> {/* floated 사용시 레이아웃 깨지는 현상 */}
          <Button content='Prev' icon='left arrow' labelPosition='left'
            onClick={this.handlePrev.bind(this)} disabled={this.checkPrevDisabled()} />
          <Button.Or />
          <Button content={this.state.currentStep === 3 ? 'Finish' : 'Next'}
            icon={this.state.currentStep === 3 ? 'send' : 'right arrow'} labelPosition='right' positive
            onClick={this.handleNext.bind(this)} disabled={this.checkNextDisabled()} />
        </Button.Group>
      </Container>
    );
  }
}
